@@ -47,7 +47,7 @@ class HomogeneousCoordinatesPoint(np.ndarray, metaclass=ABCMeta):
 
     # /!\ iter may conflict with numpy array getitem.
     def __iter__(self):
-        return (self.__class__(self[:,i]) for i in range(self.shape[1]))
+        return (self.__class__(self[:,i:i+1]) for i in range(self.shape[1]))
 
     def to_list(self):
         assert self.shape[1] == 1, "to_list() method can only be used on single point {}".format(self.__class__.__name__)
@@ -59,8 +59,16 @@ class HomogeneousCoordinatesPoint(np.ndarray, metaclass=ABCMeta):
     def to_int_tuple(self):
         return tuple(int(x) for x in self.to_list())
 
-    get_coord = lambda self, i:        super().__getitem__((i,0))        if self.shape[1] == 1 else super().__getitem__(i)
-    set_coord = lambda self, i, value: super().__setitem__((i,0), value) if self.shape[1] == 1 else super().__setitem__((i), value)
+    def linspace(self, num):
+        return np.transpose(np.linspace(self[:,:-1], self[:,1:], num), axes=(1,2,0)).reshape(3,-1)
+
+    def close(self):
+        # TODO: add Points2D and Points3D classes
+        assert self.shape[1] > 1, f"Invalid use of 'close' method: points' shape '{self.shape}' expected to be > 1 in the second dimension"
+        return self.__class__(np.hstack((self, self[:,0:1])))
+
+    get_coord = lambda self, i:        np.array(super().__getitem__((i,0)))        if self.shape[1] == 1 else np.array(super().__getitem__(i))
+    set_coord = lambda self, i, value: np.array(super().__setitem__((i,0), value)) if self.shape[1] == 1 else np.array(super().__setitem__((i), value))
 
     x = property(fget=lambda self: self.get_coord(0), fset=lambda self, value: self.set_coord(0, value))
     y = property(fget=lambda self: self.get_coord(1), fset=lambda self, value: self.set_coord(1, value))
@@ -78,8 +86,8 @@ class Point2D(HomogeneousCoordinatesPoint):
 
 class Calib():
     def __init__(self, *, width: int, height: int, T: np.ndarray, R: np.ndarray, K: np.ndarray, kc=np.zeros((5,1)), **_) -> None:
-        self.width = np.int(width)
-        self.height = np.int(height)
+        self.width = int(width)
+        self.height = int(height)
         self.T = T
         self.K = K
         self.kc = np.array(kc, dtype=np.float64)
@@ -221,6 +229,8 @@ class Calib():
         return self.update(K=A@self.K, width=new_width, height=new_height)
 
     def compute_length2D(self, length3D: int, point3D: Point3D):
+        """ Returns the length in pixel of a 3D length at point3D
+        """
         point3D_c = Point3D(np.hstack((self.R, self.T)) @ point3D.H)  # Point3D expressed in camera coordinates system
         point3D_c.x += length3D # add the 3D length to one of the componant
         point2D = self.distort(Point2D(self.K @ point3D_c)) # go in the 2D world
